@@ -78,7 +78,7 @@
     <message>
         <location filename="../shortcuts.ui" line="92"/>
         <source>Home</source>
-        <translation>Home</translation>
+        <translation>Accueil</translation>
     </message>
     <message>
         <location filename="../shortcuts.ui" line="95"/>
@@ -101,7 +101,7 @@
     <message>
         <location filename="../application.cpp" line="110"/>
         <source>DIR</source>
-        <translation>Répertoire</translation>
+        <translation>Dossier</translation>
     </message>
     <message>
         <location filename="../application.cpp" line="110"/>
@@ -356,7 +356,7 @@ en mode édition.</translation>
     <message>
         <location filename="../mainwindow.ui" line="224"/>
         <source>&amp;About</source>
-        <translation>&amp;A propos</translation>
+        <translation>&amp;À propos</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="204"/>
@@ -614,7 +614,7 @@ en mode édition.</translation>
     <message>
         <location filename="../mainwindow.ui" line="541"/>
         <source>Show Thumbnails</source>
-        <translation>Afficher les miniatures</translation>
+        <translation type="unfinished">Afficher les miniatures</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="544"/>
@@ -933,7 +933,7 @@ Rechargez l&apos;image actuelle pour voir l&apos;effet.</translation>
     <message>
         <location filename="../preferencesdialog.ui" line="183"/>
         <source>Color space:</source>
-        <translation>Espace chromatique :</translation>
+        <translation>Espace colorimétrique :</translation>
     </message>
     <message>
         <location filename="../preferencesdialog.ui" line="195"/>
