@@ -96,7 +96,7 @@
     <message>
         <location filename="../application.cpp" line="101"/>
         <source>Take a screenshot (deprecated, please use screengrab instead)</source>
-        <translation>스크린샷 찍기(더 이상 사용되지 않음, 대신 screengrab을 사용하십시오)</translation>
+        <translation>스크린숏 찍기(더 이상 사용되지 않음, 대신 screengrab을 사용해 주세요)</translation>
     </message>
     <message>
         <location filename="../application.cpp" line="110"/>
@@ -106,7 +106,7 @@
     <message>
         <location filename="../application.cpp" line="110"/>
         <source>Take a screenshot and save it to the directory without showing the GUI (deprecated, please use screengrab instead)</source>
-        <translation>스크린샷을 찍어 GUI를 표시하지 않고 디렉터리에 저장합니다(더 이상 사용되지 않음, 대신 screengrab을 사용하십시오)</translation>
+        <translation>스크린숏을 찍어 GUI를 표시하지 않고 디렉터리에 저장합니다(더 이상 사용되지 않음, 대신 screengrab을 사용하세요)</translation>
     </message>
     <message>
         <location filename="../application.cpp" line="116"/>
@@ -541,7 +541,7 @@ in the editing mode.</source>
     <message>
         <location filename="../mainwindow.ui" line="477"/>
         <source>Capture Screenshot</source>
-        <translation>스크린샷 캡처</translation>
+        <translation>스크린숏 캡처</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="485"/>
@@ -1051,17 +1051,17 @@ Reload current image to see the effect.</source>
     <message>
         <location filename="../screenshotdialog.ui" line="14"/>
         <source>Screenshot</source>
-        <translation>스크린샷</translation>
+        <translation>스크린숏</translation>
     </message>
     <message>
         <location filename="../screenshotdialog.ui" line="27"/>
         <source>Take a screenshot</source>
-        <translation>스크린샷 찍기</translation>
+        <translation>스크린숏 찍기</translation>
     </message>
     <message>
         <location filename="../screenshotdialog.ui" line="34"/>
         <source>Region</source>
-        <translation>부위</translation>
+        <translation>영역</translation>
     </message>
     <message>
         <location filename="../screenshotdialog.ui" line="40"/>
